@@ -1,7 +1,7 @@
 package WWW::Google::Contacts::Types;
 
 BEGIN {
-    $WWW::Google::Contacts::Types::VERSION = '0.22';
+    $WWW::Google::Contacts::Types::VERSION = '0.23';
 }
 
 use MooseX::Types -declare => [
@@ -86,12 +86,9 @@ class_type PhoneNumber, { class => 'WWW::Google::Contacts::Type::PhoneNumber' };
 
 coerce PhoneNumber,
   from HashRef,
-  via { WWW::Google::Contacts::Type::PhoneNumber->new($_) }, from Str, via {
-    WWW::Google::Contacts::Type::PhoneNumber->new(
-        type  => "mobile",
-        value => $_
-    );
-  };
+  via { WWW::Google::Contacts::Type::PhoneNumber->new($_) },
+  from Str,
+  via { WWW::Google::Contacts::Type::PhoneNumber->new( value => $_ ) };
 
 subtype ArrayRefOfPhoneNumber, as ArrayRef [PhoneNumber];
 
@@ -105,7 +102,7 @@ coerce Email,
   from HashRef,
   via { WWW::Google::Contacts::Type::Email->new($_) },
   from Str,
-  via { WWW::Google::Contacts::Type::Email->new( type => "home", value => $_ ) };
+  via { WWW::Google::Contacts::Type::Email->new( value => $_ ) };
 
 subtype ArrayRefOfEmail, as ArrayRef [Email];
 
@@ -132,12 +129,9 @@ class_type Organization,
 
 coerce Organization,
   from HashRef,
-  via { WWW::Google::Contacts::Type::Organization->new($_) }, from Str, via {
-    WWW::Google::Contacts::Type::Organization->new(
-        type => "work",
-        name => $_
-    );
-  };
+  via { WWW::Google::Contacts::Type::Organization->new($_) },
+  from Str,
+  via { WWW::Google::Contacts::Type::Organization->new( name => $_ ) };
 
 subtype ArrayRefOfOrganization, as ArrayRef [Organization];
 
@@ -150,12 +144,9 @@ class_type PostalAddress,
 
 coerce PostalAddress,
   from HashRef,
-  via { WWW::Google::Contacts::Type::PostalAddress->new($_) }, from Str, via {
-    WWW::Google::Contacts::Type::PostalAddress->new(
-        type      => "work",
-        formatted => $_
-    );
-  };
+  via { WWW::Google::Contacts::Type::PostalAddress->new($_) },
+  from Str,
+  via { WWW::Google::Contacts::Type::PostalAddress->new( formatted => $_ ) };
 
 subtype ArrayRefOfPostalAddress, as ArrayRef [PostalAddress];
 
